#' @keywords internal
#'
#' @section Main functions:
#' \itemize{
#'   \item Use \code{\link{spiro}} for the import and processing of
#'     cardiopulmonary exercise testing data.
#'   \item Use \code{\link{spiro_summary}} and \code{\link{spiro_max}} for
#'     a step wise summary or the maximum parameter values of the
#'     imported data.
#'   \item Use \code{\link{spiro_plot}} to visualize the data.
#' }
"_PACKAGE"


## usethis namespace: start
## usethis namespace: end
NULL
